Learn R Programming

RtutoR (version 2018.06.08)

list.ps: Returns a list of the names of all problem sets that are included in RTutor

Description

Returns a list of the names of all problem sets that are included in RTutor

Usage

list.ps()

Arguments